/*
 *	Copyright 2012  Samsung Electronics Co., Ltd
 *
 *	Licensed under the Flora License, Version 1.1 (the "License");
 *	you may not use this file except in compliance with the License.
 *	You may obtain a copy of the License at
 *
 * 		http://floralicense.org/license/
 *
 *	Unless required by applicable law or agreed to in writing, software
 *	distributed under the License is distributed on an "AS IS" BASIS,
 *	WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *	See the License for the specific language governing permissions and
 *	limitations under the License.
 */


#include "mgr-app-common-util.h"
#include "mgr-app-common-debug.h"
#include <string.h>

char *_strncpy(char *dest, const char *src, int len, char *file, int line)
{
	if (dest == NULL || src == NULL || len <= 0) {
		MGR_APP_DEBUG_ERR("STRNCPY ERROR at %s(%d)", file, line);
		return dest;
	}

	strncpy(dest, src, len);
	dest[len] = '\0';

	return dest;
}

char *_strncat(char *dest, const char *src, int dest_size, char *file, int line)
{
	if (dest == NULL || src == NULL || dest_size <= 0) {
		MGR_APP_DEBUG_ERR("STRNCAT ERROR at %s(%d)", file, line);
		return dest;
	}

	return strncat(dest, src, dest_size);
}

int _strncmp(const char *src1, const char *src2, int len, char *file, int line)
{
	if (src1 == NULL || src2 == NULL || len <= 0) {
		MGR_APP_DEBUG_ERR("STRNCMP ERROR at %s(%d)", file, line);
		return -1;
	}

	return strncmp(src1, src2, len);
}

void _strupr(char *str)
{
	int i = 0;

	if (!str || strlen(str) <= 0) {
		MGR_APP_DEBUG_ERR("STRUPR ERROR string is null");
		return;
	}

	while (str[i] != '\0') {
		if (str[i] >= 'a' && str[i] <= 'z') {
			str[i] = str[i] - ('a' - 'A');
		}
		i++;
	}
}
